

Example Project
===============
uploading first project on pypi

.. code-block:: bash

    pip install package_test7415
Usage
=====

.. code-block:: bash

    >>> from src.example import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()
    '0.24.2'
